//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[FuroChanceShantenResult](index.md)/[hand](hand.md)

# hand

[common]\
open override val [hand](hand.md): [Hand](../../mahjongutils.models.hand/-hand/index.md)&lt;[RegularHandPattern](../../mahjongutils.models.hand/-regular-hand-pattern/index.md)&gt;

手牌
